Learn R Programming

RMaCzek (version 1.6.0)

print.czek_matrix: Prints information concerning Czekanowski's Diagram

Description

This is a function that prints out information on a Czekanowski's Diagram.

Usage

# S3 method for czek_matrix
print(x, print_raw = FALSE, ...)

Value

The function returns a Czekanowski's Diagram.

Arguments

x

a matrix with class czek_matrix.

print_raw

logical, if TRUE print out raw, as if base::print() was called, in particular this prints out the matrix itself, if FALSE (default) print out a summary. Furthermore, with print_raw=TRUE the attributes "levels", "partition_boundaries" and "n_classes" defining the diagram will be printed out.

...

specifies further parameters that can be passed on to the print function.

Examples

Run this code
# Set data ####
x<-czek_matrix(mtcars)


# Standard print ############
print(x)
print.czek_matrix(x)
# Print out the raw object ############
print(x,print_raw=TRUE)
print.czek_matrix(x,print_raw=TRUE)

Run the code above in your browser using DataLab